@@ -1,12 +1,11 @@
+import copy
 import traceback
 from datetime import datetime
 from functools import wraps
-import copy
 
 import requests
 from flask import current_app as app
 from flask import request, has_request_context
-from flask_jwt_extended import get_jwt_identity
 from http_status_code.standard import bad_request
 
 
@@ -26,7 +25,9 @@ class RequestResponse:
         return message if message is None else str(message)
 
     def __call__(self, *args, **kwargs):
-        return self.__dict__
+        response = copy.deepcopy(self.__dict__)
+        status_code = response.pop('status_code')
+        return response, status_code
 
 
 class RequestUtilities:
@@ -85,6 +86,17 @@ class RequestUtilities:
         except:
             return
 
+    @staticmethod
+    def pop_email():
+        try:
+            if 'email' in request.args:
+                request.args.pop('email')
+
+            if 'email' in request.json:
+                request.json.pop('email')
+        except:
+            pass
+
     @classmethod
     def try_except(cls, fn):
         """A decorator for all of the actions to do try except"""
@@ -111,6 +123,9 @@ class RequestUtilities:
                     # pop password from args
                     cls.pop_password()
 
+                    # pop email from args
+                    cls.pop_email()
+
                     if status.code == 410:
 
                         # Format a message
@@ -124,7 +139,6 @@ class RequestUtilities:
                               f"\nStatus message: {status.message}" \
                               f"\n\nQs args\n{request.args}" \
                               f"\n\nBody args:\n{request.json}" \
-                              f"\n\nRequest context:\n{request_context}" \
                               f"\n\nArgs validation response:\n{data}"
 
                         # Log status code 410 as an exception
@@ -142,16 +156,19 @@ class RequestUtilities:
                         # Update the status message
                         RequestUtilities.update_status_message(status, data)
 
+            except Warning as w:
+                # Messages that are directed to the user
+                status.update_msg(w)
+
             except Exception as exc:
                 full_traceback = traceback.format_exc()
 
-                # Update the status message
                 RequestUtilities.update_status_message(status, exc)
 
-                # pop password from args
                 cls.pop_password()
 
-                # Format a message
+                cls.pop_email()
+
                 msg = f"{datetime.utcnow()} UTC." \
                       f"\n{app.config.get('APPLICATION_NAME')}" \
                       f"\n{app.config.get('ENV_NAME')}." \
@@ -160,7 +177,6 @@ class RequestUtilities:
                       f"\nMethod: {request.method}" \
                       f"\n\nQs args\n{request.args}" \
                       f"\n\nBody args:\n{request.json}" \
-                      f"\n\nRequest context:\n{request_context}" \
                       f"\n\nException: {exc}" \
                       f"\nException type: {type(exc)}" \
                       f"\n\nFull Traceback:\n{full_traceback}"
